#!/bin/sh
# Argument 1: Delay between slides (defaults to 10 seconds)
# Argument 2: Number of slides (defaults to 10)
# Additional arguments: Optional arguments for dfbsee

echo PDF slideshow demo - render the first N pages of a PDF to a slideshow

# Delay
DELAY=$1
if [ -z $DELAY ]; then
	DELAY=10
fi

echo Delay between slides: ${DELAY}s

# Number of slides
NR=$2
if [ -z $NR ]; then
	NR=10
fi

echo Number of slides: ${NR}

# Other Arguments
shift 2
PARAMS=$@

# Check screen geometry
geom=`fbset | grep geometry`
x=`echo $geom | awk '{ print $2 }'`
y=`echo $geom | awk '{ print $3 }'`

let X=x*3
let Y=y*4

if [ "$X" -gt "$Y" ]; then
	let SCALE=$Y/3
else
	SCALE=$x
fi 
echo Scaling to ${SCALE}

# Find PDF file, we use the first avaliable only
cd /home/root
PDFFILE=`ls /media/*/*.pdf *.pdf | head -n1` 

echo Using file: $PDFFILE

# Convert slides if not done already.
if [ ! -s slide_1.png ]; then

	for i in `seq ${NR}`; do
		pdftoppm -png -f $i -l $i -scale-to $SCALE $PDFFILE > slide_$i.png
		if [ $? -eq "0" ]; then
			echo Converted slide $i
		else
			rm slide_$i.png
		fi
	done
fi

# Run slideshow
echo Starting slideshow...  

dfbsee -s $DELAY $@ -f *.png
